@@ -1,6 +1,6 @@
-from FlaUILibrary.robotframework import keyword
-from FlaUILibrary.flaui.util import InterfaceType
-from FlaUILibrary.flaui.module import (ToggleButton, Element)
+from robotlibcore import keyword
+from FlaUILibrary.flaui.interface import InterfaceType
+from FlaUILibrary.flaui.module import ToggleButton
 
 
 class RadioButtonKeywords:
@@ -9,7 +9,8 @@ class RadioButtonKeywords:
     """
 
     def __init__(self, module):
-        """Constructor for radiobutton keywords.
+        """
+        Constructor for radiobutton keywords.
 
         ``module`` Automation framework module like UIA3 to handle element interaction.
         """
@@ -17,7 +18,8 @@ class RadioButtonKeywords:
 
     @keyword
     def select_radiobutton(self, identifier, msg=None):
-        """Select given radiobutton by xpath.
+        """
+        Select given radiobutton by xpath.
 
         XPath syntax is explained in `XPath locator`.
 
@@ -32,14 +34,15 @@ class RadioButtonKeywords:
         | Select Radiobutton  <XPATH> |
 
         """
-        element = self._module.action(Element.Action.GET_ELEMENT, identifier, msg)
+        element = self._module.get_element(identifier, InterfaceType.RADIOBUTTON, msg=msg)
         self._module.action(ToggleButton.Action.SET_TOGGLE_BUTTON_STATE,
-                            [self._module.cast_element_to_type(element, InterfaceType.RADIOBUTTON), True],
+                            self._create_value_container(element=element, state=True),
                             msg)
 
     @keyword
     def get_radiobutton_state(self, identifier, msg=None):
-        """Return actual  state ${True} or ${False} from radiobutton.
+        """
+        Return actual state ${True} or ${False} from radiobutton.
 
         XPath syntax is explained in `XPath locator`.
 
@@ -55,7 +58,15 @@ class RadioButtonKeywords:
         | Should Be Equal  ${value}  ${False/True} |
 
         """
-        element = self._module.action(Element.Action.GET_ELEMENT, identifier, msg)
+        element = self._module.get_element(identifier, InterfaceType.RADIOBUTTON, msg=msg)
         return self._module.action(ToggleButton.Action.GET_TOGGLE_BUTTON_STATE,
-                                   [self._module.cast_element_to_type(element, InterfaceType.RADIOBUTTON)],
+                                   self._create_value_container(element=element),
                                    msg)
+
+    @staticmethod
+    def _create_value_container(element=None, state=None):
+        """
+        Helper to create container object.
+        """
+        return ToggleButton.Container(element=element,
+                                      state=None if not state else bool(state))
